@@ -34,7 +34,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <QStringList>
 
 class Rules;
-class SpaceChromosome;
 class SpaceConstraint;
 class Activity;
 class Teacher;
@@ -46,6 +45,8 @@ class Building;
 class Room;
 class Solution;
 
+class QWidget;
+
 typedef QList<SpaceConstraint*> SpaceConstraintsList;
 
 const int CONSTRAINT_GENERIC_SPACE										=1000; //time constraints are beginning from 1
@@ -84,7 +85,7 @@ const int CONSTRAINT_TEACHER_MIN_GAPS_BETWEEN_BUILDING_CHANGES			=1024;
 const int CONSTRAINT_ACTIVITY_TAG_PREFERRED_ROOM						=1025;
 const int CONSTRAINT_ACTIVITY_TAG_PREFERRED_ROOMS						=1026;
 
-
+const int CONSTRAINT_ACTIVITIES_OCCUPY_MAX_DIFFERENT_ROOMS				=1027;
 
 /**
 This class represents a space constraint
@@ -97,6 +98,10 @@ public:
 	The weight (percentage) of this constraint
 	*/
 	double weightPercentage;
+	
+	bool active;
+	
+	QString comments;
 
 	/**
 	Specifies the type of this constraint (using the above constants).
@@ -120,7 +125,7 @@ public:
 	SpaceConstraint(double wp);
 
 	/**
-	The function that calculates the fitness of a space chromosome, according to this
+	The function that calculates the fitness of a solution, according to this
 	constraint. We need the rules to compute this fitness factor.
 	We need also the allocation of the activities on days and hours.
 	If conflictsString!=NULL,
@@ -136,7 +141,7 @@ public:
 	/**
 	Computes the internal structure for this constraint
 	*/
-	virtual bool computeInternalStructure(Rules& r)=0;
+	virtual bool computeInternalStructure(QWidget* parent, Rules& r)=0;
 	
 	virtual bool hasInactiveActivities(Rules& r)=0;
 
@@ -179,6 +184,10 @@ public:
 	Returns true if this constraint is related to this room
 	*/
 	virtual bool isRelatedToRoom(Room* r)=0;
+
+	virtual bool hasWrongDayOrHour(Rules& r)=0;
+	virtual bool canRepairWrongDayOrHour(Rules& r)=0;
+	virtual bool repairWrongDayOrHour(Rules& r)=0;
 };
 
 /**
@@ -193,7 +202,7 @@ public:
 
 	ConstraintBasicCompulsorySpace(double wp);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -216,6 +225,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintRoomNotAvailableTimes: public SpaceConstraint{
@@ -240,7 +253,7 @@ public:
 
 	ConstraintRoomNotAvailableTimes(double wp, const QString& rn, QList<int> d, QList<int> h);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -263,6 +276,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 /**
@@ -298,7 +315,7 @@ public:
 	*/
 	bool operator==(ConstraintActivityPreferredRoom& c);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -322,6 +339,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 /**
@@ -350,7 +371,7 @@ public:
 
 	ConstraintActivityPreferredRooms(double wp, int aid, const QStringList& roomsList);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -373,6 +394,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintStudentsSetHomeRoom: public SpaceConstraint{
@@ -395,7 +420,7 @@ public:
 
 	ConstraintStudentsSetHomeRoom(double wp, QString st, QString rm);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -418,6 +443,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintStudentsSetHomeRooms: public SpaceConstraint{
@@ -442,7 +471,7 @@ public:
 
 	ConstraintStudentsSetHomeRooms(double wp, QString st, const QStringList& rms);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -465,6 +494,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintTeacherHomeRoom: public SpaceConstraint{
@@ -487,7 +520,7 @@ public:
 
 	ConstraintTeacherHomeRoom(double wp, QString tc, QString rm);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -510,6 +543,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintTeacherHomeRooms: public SpaceConstraint{
@@ -534,7 +571,7 @@ public:
 
 	ConstraintTeacherHomeRooms(double wp, QString st, const QStringList& rms);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -557,6 +594,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 /**
@@ -583,7 +624,7 @@ public:
 
 	ConstraintSubjectPreferredRoom(double wp, const QString& subj, const QString& rm);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -607,6 +648,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 /**
@@ -632,7 +677,7 @@ public:
 
 	ConstraintSubjectPreferredRooms(double wp, const QString& subj, const QStringList& rms);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -656,6 +701,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 /**
@@ -684,7 +733,7 @@ public:
 
 	ConstraintSubjectActivityTagPreferredRoom(double wp, const QString& subj, const QString& actTag, const QString& rm);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -708,6 +757,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 /**
@@ -735,7 +788,7 @@ public:
 
 	ConstraintSubjectActivityTagPreferredRooms(double wp, const QString& subj, const QString& actTag, const QStringList& rms);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -758,6 +811,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 //addded on 6 apr 2009
@@ -781,7 +838,7 @@ public:
 
 	ConstraintActivityTagPreferredRoom(double wp, const QString& actTag, const QString& rm);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -804,6 +861,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintActivityTagPreferredRooms: public SpaceConstraint{
@@ -825,7 +886,7 @@ public:
 
 	ConstraintActivityTagPreferredRooms(double wp, const QString& actTag, const QStringList& rms);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -848,6 +909,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 ///////
 
@@ -868,7 +933,7 @@ public:
 
 	ConstraintStudentsSetMaxBuildingChangesPerDay(double wp, QString st, int mc);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	QString getXmlDescription(Rules& r);
 
@@ -891,6 +956,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintStudentsMaxBuildingChangesPerDay: public SpaceConstraint{
@@ -904,7 +973,7 @@ public:
 
 	ConstraintStudentsMaxBuildingChangesPerDay(double wp, int mc);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	QString getXmlDescription(Rules& r);
 
@@ -927,6 +996,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintStudentsSetMaxBuildingChangesPerWeek: public SpaceConstraint{
@@ -946,7 +1019,7 @@ public:
 
 	ConstraintStudentsSetMaxBuildingChangesPerWeek(double wp, QString st, int mc);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	QString getXmlDescription(Rules& r);
 
@@ -969,6 +1042,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintStudentsMaxBuildingChangesPerWeek: public SpaceConstraint{
@@ -982,7 +1059,7 @@ public:
 
 	ConstraintStudentsMaxBuildingChangesPerWeek(double wp, int mc);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	QString getXmlDescription(Rules& r);
 
@@ -1005,6 +1082,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintStudentsSetMinGapsBetweenBuildingChanges: public SpaceConstraint{
@@ -1024,7 +1105,7 @@ public:
 
 	ConstraintStudentsSetMinGapsBetweenBuildingChanges(double wp, QString st, int mg);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	QString getXmlDescription(Rules& r);
 
@@ -1047,6 +1128,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintStudentsMinGapsBetweenBuildingChanges: public SpaceConstraint{
@@ -1060,7 +1145,7 @@ public:
 
 	ConstraintStudentsMinGapsBetweenBuildingChanges(double wp, int mg);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	QString getXmlDescription(Rules& r);
 
@@ -1083,6 +1168,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintTeacherMaxBuildingChangesPerDay: public SpaceConstraint{
@@ -1102,7 +1191,7 @@ public:
 
 	ConstraintTeacherMaxBuildingChangesPerDay(double wp, QString tc, int mc);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	QString getXmlDescription(Rules& r);
 
@@ -1125,6 +1214,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintTeachersMaxBuildingChangesPerDay: public SpaceConstraint{
@@ -1138,7 +1231,7 @@ public:
 
 	ConstraintTeachersMaxBuildingChangesPerDay(double wp, int mc);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -1161,6 +1254,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintTeacherMaxBuildingChangesPerWeek: public SpaceConstraint{
@@ -1180,7 +1277,7 @@ public:
 
 	ConstraintTeacherMaxBuildingChangesPerWeek(double wp, QString tc, int mc);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -1203,6 +1300,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintTeachersMaxBuildingChangesPerWeek: public SpaceConstraint{
@@ -1216,7 +1317,7 @@ public:
 
 	ConstraintTeachersMaxBuildingChangesPerWeek(double wp, int mc);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -1239,6 +1340,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintTeacherMinGapsBetweenBuildingChanges: public SpaceConstraint{
@@ -1258,7 +1363,7 @@ public:
 
 	ConstraintTeacherMinGapsBetweenBuildingChanges(double wp, QString tc, int mg);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -1281,6 +1386,10 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
 class ConstraintTeachersMinGapsBetweenBuildingChanges: public SpaceConstraint{
@@ -1294,7 +1403,7 @@ public:
 
 	ConstraintTeachersMinGapsBetweenBuildingChanges(double wp, int mg);
 
-	bool computeInternalStructure(Rules& r);
+	bool computeInternalStructure(QWidget* parent, Rules& r);
 
 	bool hasInactiveActivities(Rules& r);
 	
@@ -1317,8 +1426,56 @@ public:
 	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
 
 	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
 };
 
+class ConstraintActivitiesOccupyMaxDifferentRooms: public SpaceConstraint{
+	Q_DECLARE_TR_FUNCTIONS(ConstraintActivitiesOccupyMaxDifferentRooms)
 
+public:
+	QList<int> activitiesIds;
+	
+	int maxDifferentRooms;
+
+	//internal variables
+	QList<int> _activitiesIndices;
+
+	ConstraintActivitiesOccupyMaxDifferentRooms();
+
+	ConstraintActivitiesOccupyMaxDifferentRooms(double wp, QList<int> a_L, int max_rooms);
+
+	bool computeInternalStructure(QWidget* parent, Rules& r);
+
+	bool hasInactiveActivities(Rules& r);
+
+	QString getXmlDescription(Rules& r);
+
+	QString getDescription(Rules& r);
+
+	QString getDetailedDescription(Rules& r);
+
+	double fitness(Solution& c, Rules& r, QList<double>& cl, QList<QString>&dl, QString* conflictsString=NULL);
+
+	void removeUseless(Rules& r);
+
+	bool isRelatedToActivity(Activity* a);
+	
+	bool isRelatedToTeacher(Teacher* t);
+
+	bool isRelatedToSubject(Subject* s);
+
+	bool isRelatedToActivityTag(ActivityTag* s);
+	
+	bool isRelatedToStudentsSet(Rules& r, StudentsSet* s);
+
+	bool isRelatedToRoom(Room* r);
+
+	bool hasWrongDayOrHour(Rules& r);
+	bool canRepairWrongDayOrHour(Rules& r);
+	bool repairWrongDayOrHour(Rules& r);
+};
 
 #endif
