@@ -34,7 +34,7 @@ private:
 public:
 	ActivitiesList visibleActivitiesList;
 
-	ActivitiesForm(const QString& teacherName, const QString& studentsSetName, const QString& subjectName, const QString& activityTagName);
+	ActivitiesForm(QWidget* parent, const QString& teacherName, const QString& studentsSetName, const QString& subjectName, const QString& activityTagName);
 	~ActivitiesForm();
 
 	bool filterOk(Activity* act);
@@ -49,6 +49,8 @@ public slots:
 	void studentsFilterChanged();
 	
 	void help();
+	
+	void activityComments();
 };
 
 #endif
