@@ -17,57 +17,58 @@
 
 #include <QMessageBox>
 
-#include <cstdio>
+
 
 #include "longtextmessagebox.h"
 
 #include "addconstraintactivitytagpreferredroomsform.h"
 #include "spaceconstraint.h"
 
-AddConstraintActivityTagPreferredRoomsForm::AddConstraintActivityTagPreferredRoomsForm()
+#include <QListWidget>
+#include <QAbstractItemView>
+
+AddConstraintActivityTagPreferredRoomsForm::AddConstraintActivityTagPreferredRoomsForm(QWidget* parent): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-//    connect(addPushButton, SIGNAL(clicked()), this, SLOT(addRoom()));
-//    connect(removePushButton, SIGNAL(clicked()), this, SLOT(removeRoom()));
-    connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
-    connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addConstraint()));
-    connect(roomsListBox, SIGNAL(selected(QString)), this, SLOT(addRoom()));
-    connect(selectedRoomsListBox, SIGNAL(selected(QString)), this, SLOT(removeRoom()));
+	addConstraintPushButton->setDefault(true);
 
-    connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
+	roomsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+	selectedRoomsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+
+	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
+	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addConstraint()));
+	connect(roomsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(addRoom()));
+	connect(selectedRoomsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(removeRoom()));
+	connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
 
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 	
 	QSize tmp4=activityTagsComboBox->minimumSizeHint();
 	Q_UNUSED(tmp4);
 
-	updateRoomsListBox();
+	updateRoomsListWidget();
 	
 	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
 		ActivityTag* sb=gt.rules.activityTagsList[i];
-		activityTagsComboBox->insertItem(sb->name);
+		activityTagsComboBox->addItem(sb->name);
 	}
 }
 
 AddConstraintActivityTagPreferredRoomsForm::~AddConstraintActivityTagPreferredRoomsForm()
 {
+	saveFETDialogGeometry(this);
 }
 
-void AddConstraintActivityTagPreferredRoomsForm::updateRoomsListBox()
+void AddConstraintActivityTagPreferredRoomsForm::updateRoomsListWidget()
 {
-	roomsListBox->clear();
-	selectedRoomsListBox->clear();
+	roomsListWidget->clear();
+	selectedRoomsListWidget->clear();
 
 	for(int i=0; i<gt.rules.roomsList.size(); i++){
 		Room* rm=gt.rules.roomsList[i];
-		roomsListBox->insertItem(rm->name);
+		roomsListWidget->addItem(rm->name);
 	}
 }
 
@@ -77,32 +78,25 @@ void AddConstraintActivityTagPreferredRoomsForm::addConstraint()
 
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid weight"));
 		return;
 	}
 
-	if(selectedRoomsListBox->count()==0){
+	if(selectedRoomsListWidget->count()==0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Empty list of selected rooms"));
 		return;
 	}
-	if(selectedRoomsListBox->count()==1){
+	if(selectedRoomsListWidget->count()==1){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Only one selected room - please use constraint activity tag preferred room if you want a single room"));
 		return;
 	}
 	
-/*	if(subjectsComboBox->currentItem()<0 || subjectsComboBox->count()<=0){
-		QMessageBox::warning(this, tr("FET information"),
-			tr("Invalid selected subject"));
-		return;	
-	}
-	QString subject=subjectsComboBox->currentText();*/
-	
-	if(activityTagsComboBox->currentItem()<0 || activityTagsComboBox->count()<=0){
+	if(activityTagsComboBox->currentIndex()<0 || activityTagsComboBox->count()<=0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid selected activity tag"));
 		return;	
@@ -110,10 +104,10 @@ void AddConstraintActivityTagPreferredRoomsForm::addConstraint()
 	QString activityTag=activityTagsComboBox->currentText();
 	
 	QStringList roomsList;
-	for(uint i=0; i<selectedRoomsListBox->count(); i++)
-		roomsList.append(selectedRoomsListBox->text(i));
+	for(int i=0; i<selectedRoomsListWidget->count(); i++)
+		roomsList.append(selectedRoomsListWidget->item(i)->text());
 	
-	ctr=new ConstraintActivityTagPreferredRooms(weight, /* subject,*/ activityTag, roomsList);
+	ctr=new ConstraintActivityTagPreferredRooms(weight, activityTag, roomsList);
 	bool tmp2=gt.rules.addSpaceConstraint(ctr);
 	
 	if(tmp2){
@@ -131,28 +125,37 @@ void AddConstraintActivityTagPreferredRoomsForm::addConstraint()
 
 void AddConstraintActivityTagPreferredRoomsForm::addRoom()
 {
-	if(roomsListBox->currentItem()<0)
+	if(roomsListWidget->currentRow()<0)
 		return;
-	QString rmName=roomsListBox->currentText();
+	QString rmName=roomsListWidget->currentItem()->text();
 	assert(rmName!="");
-	uint i;
+	int i;
 	//duplicate?
-	for(i=0; i<selectedRoomsListBox->count(); i++)
-		if(rmName==selectedRoomsListBox->text(i))
+	for(i=0; i<selectedRoomsListWidget->count(); i++)
+		if(rmName==selectedRoomsListWidget->item(i)->text())
 			break;
-	if(i<selectedRoomsListBox->count())
+	if(i<selectedRoomsListWidget->count())
 		return;
-	selectedRoomsListBox->insertItem(rmName);
+	selectedRoomsListWidget->addItem(rmName);
+	selectedRoomsListWidget->setCurrentRow(selectedRoomsListWidget->count()-1);
 }
 
 void AddConstraintActivityTagPreferredRoomsForm::removeRoom()
 {
-	if(selectedRoomsListBox->currentItem()<0 || selectedRoomsListBox->count()<=0)
-		return;		
-	selectedRoomsListBox->removeItem(selectedRoomsListBox->currentItem());
+	if(selectedRoomsListWidget->currentRow()<0 || selectedRoomsListWidget->count()<=0)
+		return;
+	int tmp=selectedRoomsListWidget->currentRow();
+	
+	selectedRoomsListWidget->setCurrentRow(-1);
+	QListWidgetItem* item=selectedRoomsListWidget->takeItem(tmp);
+	delete item;
+	if(tmp<selectedRoomsListWidget->count())
+		selectedRoomsListWidget->setCurrentRow(tmp);
+	else
+		selectedRoomsListWidget->setCurrentRow(selectedRoomsListWidget->count()-1);
 }
 
 void AddConstraintActivityTagPreferredRoomsForm::clear()
 {
-	selectedRoomsListBox->clear();
+	selectedRoomsListWidget->clear();
 }
