@@ -17,75 +17,39 @@
 
 #include <QMessageBox>
 
-#include <cstdio>
-
 #include "longtextmessagebox.h"
 
 #include "addconstraintteachersmaxdaysperweekform.h"
 #include "timeconstraint.h"
 
-
-AddConstraintTeachersMaxDaysPerWeekForm::AddConstraintTeachersMaxDaysPerWeekForm()
+AddConstraintTeachersMaxDaysPerWeekForm::AddConstraintTeachersMaxDaysPerWeekForm(QWidget* parent): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-//    connect(weightLineEdit, SIGNAL(textChanged(QString)), this /*AddConstraintTeachersMaxDaysPerWeekForm_template*/, SLOT(constraintChanged()));
-    connect(addConstraintPushButton, SIGNAL(clicked()), this /*AddConstraintTeachersMaxDaysPerWeekForm_template*/, SLOT(addCurrentConstraint()));
-    connect(closePushButton, SIGNAL(clicked()), this /*AddConstraintTeachersMaxDaysPerWeekForm_template*/, SLOT(close()));
-//    connect(maxDaysSpinBox, SIGNAL(valueChanged(int)), this /*AddConstraintTeachersMaxDaysPerWeekForm_template*/, SLOT(constraintChanged()));
+	addConstraintPushButton->setDefault(true);
 
+	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
+	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
 
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 	
 	updateMaxDaysSpinBox();
-	//updateTeachersComboBox();
 }
 
 AddConstraintTeachersMaxDaysPerWeekForm::~AddConstraintTeachersMaxDaysPerWeekForm()
 {
+	saveFETDialogGeometry(this);
 }
 
-/*void AddConstraintTeachersMaxDaysPerWeekForm::updateTeachersComboBox(){
-	teachersComboBox->clear();
-	for(int i=0; i<gt.rules.teachersList.size(); i++){
-		Teacher* tch=gt.rules.teachersList[i];
-		teachersComboBox->insertItem(tch->name);
-	}
-
-	constraintChanged();
-}*/
-
 void AddConstraintTeachersMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
-	maxDaysSpinBox->setMinValue(1);
-	maxDaysSpinBox->setMaxValue(gt.rules.nDaysPerWeek);
+	maxDaysSpinBox->setMinimum(1);
+	maxDaysSpinBox->setMaximum(gt.rules.nDaysPerWeek);
 	maxDaysSpinBox->setValue(gt.rules.nDaysPerWeek);
 }
 
 void AddConstraintTeachersMaxDaysPerWeekForm::constraintChanged()
-{/*
-	QString s;
-	s+=tr("Current constraint:");
-	s+="\n";
-
-	double weight;
-	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
-	s+=tr("Weight (percentage)=%1").arg(weight);
-	s+="\n";
-
-	s+=tr("Teachers max days per week");
-	s+="\n";
-
-	s+=tr("Max days per week=%1").arg(maxDaysSpinBox->value());
-	s+="\n";
-
-	currentConstraintTextEdit->setText(s);*/
+{
 }
 
 void AddConstraintTeachersMaxDaysPerWeekForm::addCurrentConstraint()
@@ -94,7 +58,7 @@ void AddConstraintTeachersMaxDaysPerWeekForm::addCurrentConstraint()
 
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid weight (percentage)"));
@@ -105,22 +69,10 @@ void AddConstraintTeachersMaxDaysPerWeekForm::addCurrentConstraint()
 			tr("Invalid weight (percentage) - it has to be 100%"));
 		return;
 	}
-
-	/*bool compulsory=false;
-	if(compulsoryCheckBox->isChecked())
-		compulsory=true;*/
-
+	
 	int max_days=maxDaysSpinBox->value();
 
-/*	QString teacher_name=teachersComboBox->currentText();
-	int teacher_ID=gt.rules.searchTeacher(teacher_name);
-	if(teacher_ID<0){
-		QMessageBox::warning(this, tr("FET information"),
-			tr("Invalid teacher"));
-		return;
-	}*/
-
-	ctr=new ConstraintTeachersMaxDaysPerWeek(weight, /*compulsory,*/ max_days/*, teacher_name*/);
+	ctr=new ConstraintTeachersMaxDaysPerWeek(weight, max_days);
 
 	bool tmp2=gt.rules.addTimeConstraint(ctr);
 	if(tmp2)
