@@ -17,35 +17,26 @@
 
 #include <QMessageBox>
 
-#include <cstdio>
-
 #include "longtextmessagebox.h"
 
 #include "addconstrainttwoactivitiesorderedform.h"
 #include "timeconstraint.h"
 
-AddConstraintTwoActivitiesOrderedForm::AddConstraintTwoActivitiesOrderedForm()
+AddConstraintTwoActivitiesOrderedForm::AddConstraintTwoActivitiesOrderedForm(QWidget* parent): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-//    connect(weightLineEdit, SIGNAL(textChanged(QString)), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(constraintChanged()));
-    connect(addConstraintPushButton, SIGNAL(clicked()), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(addCurrentConstraint()));
-    connect(closePushButton, SIGNAL(clicked()), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(close()));
-//    connect(firstActivitiesComboBox, SIGNAL(activated(QString)), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(constraintChanged()));
-//    connect(secondActivitiesComboBox, SIGNAL(activated(QString)), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(constraintChanged()));
-    connect(teachersComboBox, SIGNAL(activated(QString)), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(filterChanged()));
-    connect(studentsComboBox, SIGNAL(activated(QString)), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(filterChanged()));
-    connect(subjectsComboBox, SIGNAL(activated(QString)), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(filterChanged()));
-    connect(activityTagsComboBox, SIGNAL(activated(QString)), this /*AddConstraintTwoActivitiesOrderedForm_template*/, SLOT(filterChanged()));
+	addConstraintPushButton->setDefault(true);
 
+	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
+	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
+	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
-	//setWindowFlags(Qt::Window);
-	//setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	/*QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 	
 	QSize tmp1=teachersComboBox->minimumSizeHint();
 	Q_UNUSED(tmp1);
@@ -64,47 +55,48 @@ AddConstraintTwoActivitiesOrderedForm::AddConstraintTwoActivitiesOrderedForm()
 	firstActivitiesComboBox->setMaximumWidth(maxRecommendedWidth(this));
 	secondActivitiesComboBox->setMaximumWidth(maxRecommendedWidth(this));
 	
-	teachersComboBox->insertItem("");
+	teachersComboBox->addItem("");
 	for(int i=0; i<gt.rules.teachersList.size(); i++){
 		Teacher* tch=gt.rules.teachersList[i];
-		teachersComboBox->insertItem(tch->name);
+		teachersComboBox->addItem(tch->name);
 	}
-	teachersComboBox->setCurrentItem(0);
+	teachersComboBox->setCurrentIndex(0);
 
-	subjectsComboBox->insertItem("");
+	subjectsComboBox->addItem("");
 	for(int i=0; i<gt.rules.subjectsList.size(); i++){
 		Subject* sb=gt.rules.subjectsList[i];
-		subjectsComboBox->insertItem(sb->name);
+		subjectsComboBox->addItem(sb->name);
 	}
-	subjectsComboBox->setCurrentItem(0);
+	subjectsComboBox->setCurrentIndex(0);
 
-	activityTagsComboBox->insertItem("");
+	activityTagsComboBox->addItem("");
 	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
 		ActivityTag* st=gt.rules.activityTagsList[i];
-		activityTagsComboBox->insertItem(st->name);
+		activityTagsComboBox->addItem(st->name);
 	}
-	activityTagsComboBox->setCurrentItem(0);
+	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->insertItem("");
+	studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->insertItem(sty->name);
+		studentsComboBox->addItem(sty->name);
 		for(int j=0; j<sty->groupsList.size(); j++){
 			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->insertItem(stg->name);
+			studentsComboBox->addItem(stg->name);
 			for(int k=0; k<stg->subgroupsList.size(); k++){
 				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->insertItem(sts->name);
+				studentsComboBox->addItem(sts->name);
 			}
 		}
 	}
-	studentsComboBox->setCurrentItem(0);
+	studentsComboBox->setCurrentIndex(0);
 
 	updateActivitiesComboBox();
 }
 
 AddConstraintTwoActivitiesOrderedForm::~AddConstraintTwoActivitiesOrderedForm()
 {
+	saveFETDialogGeometry(this);
 }
 
 bool AddConstraintTwoActivitiesOrderedForm::filterOk(Activity* act)
@@ -132,7 +124,6 @@ bool AddConstraintTwoActivitiesOrderedForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-//	if(sbtn!="" && sbtn!=act->activityTagName)
 	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
 		ok=false;
 		
@@ -162,10 +153,10 @@ void AddConstraintTwoActivitiesOrderedForm::updateActivitiesComboBox(){
 		Activity* act=gt.rules.activitiesList[i];
 		
 		if(filterOk(act)){
-			firstActivitiesComboBox->insertItem(act->getDescription(gt.rules));
+			firstActivitiesComboBox->addItem(act->getDescription(gt.rules));
 			this->firstActivitiesList.append(act->id);
 
-			secondActivitiesComboBox->insertItem(act->getDescription(gt.rules));
+			secondActivitiesComboBox->addItem(act->getDescription(gt.rules));
 			this->secondActivitiesList.append(act->id);
 		}
 	}
@@ -179,49 +170,7 @@ void AddConstraintTwoActivitiesOrderedForm::filterChanged()
 }
 
 void AddConstraintTwoActivitiesOrderedForm::constraintChanged()
-{/*
-	QString s;
-	s+=tr("Current constraint:");
-	s+="\n";
-
-	double weight;
-	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
-	s+=tr("Weight (percentage)=%1\%").arg(weight);
-	s+="\n";
-
-	s+=tr("two activities ordered");
-	s+=" ";
-	s+=tr("(activity 2 must be after activity 1, separated by any number of days or hours)");
-	s+="\n";
-
-	int tmp2=firstActivitiesComboBox->currentItem();
-	assert(tmp2<firstActivitiesList.size());
-	assert(tmp2<gt.rules.activitiesList.size());
-	if(tmp2<0){
-		s+=tr("Invalid first activity");
-		s+="\n";
-	}
-	else{
-		int fid=firstActivitiesList.at(tmp2);
-		s+=tr("First activity id=%1").arg(fid);
-		s+="\n";
-	}
-
-	int tmp3=secondActivitiesComboBox->currentItem();
-	assert(tmp3<secondActivitiesList.size());
-	assert(tmp3<gt.rules.activitiesList.size());
-	if(tmp3<0){
-		s+=tr("Invalid second activity");
-		s+="\n";
-	}
-	else{
-		int sid=secondActivitiesList.at(tmp3);
-		s+=tr("Second activity id=%1").arg(sid);
-		s+="\n";
-	}
-
-	currentConstraintTextEdit->setText(s);*/
+{
 }
 
 void AddConstraintTwoActivitiesOrderedForm::addCurrentConstraint()
@@ -230,7 +179,7 @@ void AddConstraintTwoActivitiesOrderedForm::addCurrentConstraint()
 
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid weight (percentage)"));
@@ -238,7 +187,7 @@ void AddConstraintTwoActivitiesOrderedForm::addCurrentConstraint()
 	}
 
 	int fid;
-	int tmp2=firstActivitiesComboBox->currentItem();
+	int tmp2=firstActivitiesComboBox->currentIndex();
 	assert(tmp2<gt.rules.activitiesList.size());
 	assert(tmp2<firstActivitiesList.size());
 	if(tmp2<0){
@@ -250,7 +199,7 @@ void AddConstraintTwoActivitiesOrderedForm::addCurrentConstraint()
 		fid=firstActivitiesList.at(tmp2);
 	
 	int sid;
-	int tmp3=secondActivitiesComboBox->currentItem();
+	int tmp3=secondActivitiesComboBox->currentIndex();
 	assert(tmp3<gt.rules.activitiesList.size());
 	assert(tmp3<secondActivitiesList.size());
 	if(tmp3<0){
