@@ -23,72 +23,78 @@
 #include "addconstraintactivitytagpreferredroomsform.h"
 #include "modifyconstraintactivitytagpreferredroomsform.h"
 
-ConstraintActivityTagPreferredRoomsForm::ConstraintActivityTagPreferredRoomsForm()
+#include <QListWidget>
+#include <QScrollBar>
+#include <QAbstractItemView>
+
+ConstraintActivityTagPreferredRoomsForm::ConstraintActivityTagPreferredRoomsForm(QWidget* parent): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-    connect(addConstraintPushButton, SIGNAL(clicked()), this /*ConstraintActivityTagPreferredRoomsForm_template*/, SLOT(addConstraint()));
-    connect(removeConstraintPushButton, SIGNAL(clicked()), this /*ConstraintActivityTagPreferredRoomsForm_template*/, SLOT(removeConstraint()));
-    connect(closePushButton, SIGNAL(clicked()), this /*ConstraintActivityTagPreferredRoomsForm_template*/, SLOT(close()));
-    connect(constraintsListBox, SIGNAL(highlighted(int)), this /*ConstraintActivityTagPreferredRoomsForm_template*/, SLOT(constraintChanged(int)));
-    connect(modifyConstraintPushButton, SIGNAL(clicked()), this /*ConstraintActivityTagPreferredRoomsForm_template*/, SLOT(modifyConstraint()));
-    connect(constraintsListBox, SIGNAL(selected(QString)), this /*ConstraintActivityTagPreferredRoomsForm_template*/, SLOT(modifyConstraint()));
-    connect(activityTagsComboBox, SIGNAL(activated(QString)), this /*ConstraintActivityTagPreferredRoomsForm_template*/, SLOT(filterChanged()));
+	currentConstraintTextEdit->setReadOnly(true);
+	
+	modifyConstraintPushButton->setDefault(true);
 
+	constraintsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+
+	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addConstraint()));
+	connect(removeConstraintPushButton, SIGNAL(clicked()), this, SLOT(removeConstraint()));
+	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
+	connect(constraintsListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(constraintChanged(int)));
+	connect(modifyConstraintPushButton, SIGNAL(clicked()), this, SLOT(modifyConstraint()));
+	connect(constraintsListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(modifyConstraint()));
+	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 
 	QSize tmp4=activityTagsComboBox->minimumSizeHint();
 	Q_UNUSED(tmp4);
 	
-	activityTagsComboBox->insertItem("");
+	activityTagsComboBox->addItem("");
 	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
 		ActivityTag* sb=gt.rules.activityTagsList[i];
-		activityTagsComboBox->insertItem(sb->name);
+		activityTagsComboBox->addItem(sb->name);
 	}
 
-	this->refreshConstraintsListBox();
+	this->refreshConstraintsListWidget();
 }
 
 ConstraintActivityTagPreferredRoomsForm::~ConstraintActivityTagPreferredRoomsForm()
 {
+	saveFETDialogGeometry(this);
 }
 
-void ConstraintActivityTagPreferredRoomsForm::refreshConstraintsListBox()
+void ConstraintActivityTagPreferredRoomsForm::refreshConstraintsListWidget()
 {
-	this->visibleConstraintsList.clear();
-	constraintsListBox->clear();
+	visibleConstraintsList.clear();
+	constraintsListWidget->clear();
 	for(int i=0; i<gt.rules.spaceConstraintsList.size(); i++){
 		SpaceConstraint* ctr=gt.rules.spaceConstraintsList[i];
 		if(filterOk(ctr)){
 			QString s;
 			s=ctr->getDescription(gt.rules);
 			visibleConstraintsList.append(ctr);
-			constraintsListBox->insertItem(s);
+			constraintsListWidget->addItem(s);
 		}
 	}
 
-	constraintsListBox->setCurrentItem(0);
-	this->constraintChanged(constraintsListBox->currentItem());
+	if(constraintsListWidget->count()>0)
+		constraintsListWidget->setCurrentRow(0);
+	else
+		currentConstraintTextEdit->setPlainText(QString(""));
 }
 
 void ConstraintActivityTagPreferredRoomsForm::filterChanged()
 {
-	this->refreshConstraintsListBox();
+	this->refreshConstraintsListWidget();
 }
 
 bool ConstraintActivityTagPreferredRoomsForm::filterOk(SpaceConstraint* ctr)
 {
 	if(ctr->type==CONSTRAINT_ACTIVITY_TAG_PREFERRED_ROOMS){
 		ConstraintActivityTagPreferredRooms* c=(ConstraintActivityTagPreferredRooms*)ctr;
-		return //(c->subjectName==subjectsComboBox->currentText() || subjectsComboBox->currentText()=="") &&
-		 (c->activityTagName==activityTagsComboBox->currentText() || activityTagsComboBox->currentText()=="");
+		return (c->activityTagName==activityTagsComboBox->currentText() || activityTagsComboBox->currentText()=="");
 	}
 	else
 		return false;
@@ -97,7 +103,7 @@ bool ConstraintActivityTagPreferredRoomsForm::filterOk(SpaceConstraint* ctr)
 void ConstraintActivityTagPreferredRoomsForm::constraintChanged(int index)
 {
 	if(index<0){
-		currentConstraintTextEdit->setText("");
+		currentConstraintTextEdit->setPlainText("");
 		return;
 	}
 	QString s;
@@ -105,39 +111,53 @@ void ConstraintActivityTagPreferredRoomsForm::constraintChanged(int index)
 	SpaceConstraint* ctr=this->visibleConstraintsList.at(index);
 	assert(ctr!=NULL);
 	s=ctr->getDetailedDescription(gt.rules);
-	currentConstraintTextEdit->setText(s);
+	currentConstraintTextEdit->setPlainText(s);
 }
 
 void ConstraintActivityTagPreferredRoomsForm::addConstraint()
 {
-	AddConstraintActivityTagPreferredRoomsForm form;
+	AddConstraintActivityTagPreferredRoomsForm form(this);
+	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListBox();
+	this->refreshConstraintsListWidget();
 	
-	constraintsListBox->setCurrentItem(constraintsListBox->count()-1);
+	constraintsListWidget->setCurrentRow(constraintsListWidget->count()-1);
 }
 
 void ConstraintActivityTagPreferredRoomsForm::modifyConstraint()
 {
-	int i=constraintsListBox->currentItem();
+	int valv=constraintsListWidget->verticalScrollBar()->value();
+	int valh=constraintsListWidget->horizontalScrollBar()->value();
+
+	int i=constraintsListWidget->currentRow();
 	if(i<0){
 		QMessageBox::information(this, tr("FET information"), tr("Invalid selected constraint"));
 		return;
 	}
 	SpaceConstraint* ctr=this->visibleConstraintsList.at(i);
 
-	ModifyConstraintActivityTagPreferredRoomsForm form((ConstraintActivityTagPreferredRooms*)ctr);
+	ModifyConstraintActivityTagPreferredRoomsForm form(this, (ConstraintActivityTagPreferredRooms*)ctr);
+	setParentAndOtherThings(&form, this);
 	form.exec();
 
-	this->refreshConstraintsListBox();
+	this->refreshConstraintsListWidget();
 	
-	constraintsListBox->setCurrentItem(i);
+	constraintsListWidget->verticalScrollBar()->setValue(valv);
+	constraintsListWidget->horizontalScrollBar()->setValue(valh);
+
+	if(i>=constraintsListWidget->count())
+		i=constraintsListWidget->count()-1;
+
+	if(i>=0)
+		constraintsListWidget->setCurrentRow(i);
+	else
+		this->constraintChanged(-1);
 }
 
 void ConstraintActivityTagPreferredRoomsForm::removeConstraint()
 {
-	int i=constraintsListBox->currentItem();
+	int i=constraintsListWidget->currentRow();
 	if(i<0){
 		QMessageBox::information(this, tr("FET information"), tr("Invalid selected constraint"));
 		return;
@@ -147,18 +167,28 @@ void ConstraintActivityTagPreferredRoomsForm::removeConstraint()
 	s=tr("Remove constraint?");
 	s+="\n\n";
 	s+=ctr->getDetailedDescription(gt.rules);
-	//s+=tr("\nAre you sure?");
+	
+	QListWidgetItem* item;
 
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
 		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
-	case 0: // The user clicked the OK again button or pressed Enter
+	case 0: // The user clicked the OK button or pressed Enter
 		gt.rules.removeSpaceConstraint(ctr);
-		this->refreshConstraintsListBox();
+
+		visibleConstraintsList.removeAt(i);
+		constraintsListWidget->setCurrentRow(-1);
+		item=constraintsListWidget->takeItem(i);
+		delete item;
+
 		break;
-	case 1: // The user clicked the Cancel or pressed Escape
+	case 1: // The user clicked the Cancel button or pressed Escape
 		break;
 	}
-	if((uint)(i) >= constraintsListBox->count())
-		i=constraintsListBox->count()-1;
-	constraintsListBox->setCurrentItem(i);
+	
+	if(i>=constraintsListWidget->count())
+		i=constraintsListWidget->count()-1;
+	if(i>=0)
+		constraintsListWidget->setCurrentRow(i);
+	else
+		this->constraintChanged(-1);
 }
