@@ -17,34 +17,35 @@
 
 #include <QMessageBox>
 
-#include <cstdio>
-
 #include "modifyconstraintactivitiesnotoverlappingform.h"
-#include "spaceconstraint.h"
+#include "fet.h"
 
-ModifyConstraintActivitiesNotOverlappingForm::ModifyConstraintActivitiesNotOverlappingForm(ConstraintActivitiesNotOverlapping* ctr)
+#include <QListWidget>
+#include <QAbstractItemView>
+#include <QScrollBar>
+
+ModifyConstraintActivitiesNotOverlappingForm::ModifyConstraintActivitiesNotOverlappingForm(QWidget* parent, ConstraintActivitiesNotOverlapping* ctr): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintActivitiesNotOverlappingForm_template*/, SLOT(cancel()));
-    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintActivitiesNotOverlappingForm_template*/, SLOT(ok()));
-    connect(activitiesListBox, SIGNAL(selected(QString)), this/*ModifyConstraintActivitiesNotOverlappingForm_template*/, SLOT(addActivity()));
-    connect(notOverlappingActivitiesListBox, SIGNAL(selected(QString)), this /*ModifyConstraintActivitiesNotOverlappingForm_template*/, SLOT(removeActivity()));
-    connect(teachersComboBox, SIGNAL(activated(QString)), this /*ModifyConstraintActivitiesNotOverlappingForm_template*/, SLOT(filterChanged()));
-    connect(studentsComboBox, SIGNAL(activated(QString)), this /*ModifyConstraintActivitiesNotOverlappingForm_template*/, SLOT(filterChanged()));
-    connect(subjectsComboBox, SIGNAL(activated(QString)), this /*ModifyConstraintActivitiesNotOverlappingForm_template*/, SLOT(filterChanged()));
-    connect(activityTagsComboBox, SIGNAL(activated(QString)), this /*ModifyConstraintActivitiesNotOverlappingForm_template*/, SLOT(filterChanged()));
+	okPushButton->setDefault(true);
 
-    connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
+	activitiesListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+	notOverlappingActivitiesListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
 
+	connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(cancel()));
+	connect(okPushButton, SIGNAL(clicked()), this, SLOT(ok()));
+	connect(activitiesListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(addActivity()));
+	connect(addAllActivitiesPushButton, SIGNAL(clicked()), this, SLOT(addAllActivities()));
+	connect(notOverlappingActivitiesListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(removeActivity()));
+	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
+	connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
 
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 
 	QSize tmp1=teachersComboBox->minimumSizeHint();
 	Q_UNUSED(tmp1);
@@ -56,10 +57,9 @@ ModifyConstraintActivitiesNotOverlappingForm::ModifyConstraintActivitiesNotOverl
 	Q_UNUSED(tmp4);
 		
 	this->_ctr=ctr;
-	//updateActivitiesListBox();
 	
 	notOverlappingActivitiesList.clear();
-	notOverlappingActivitiesListBox->clear();	
+	notOverlappingActivitiesListWidget->clear();
 	for(int i=0; i<ctr->n_activities; i++){
 		int actId=ctr->activitiesId[i];
 		this->notOverlappingActivitiesList.append(actId);
@@ -70,101 +70,71 @@ ModifyConstraintActivitiesNotOverlappingForm::ModifyConstraintActivitiesNotOverl
 				break;
 		}
 		assert(act);
-		this->notOverlappingActivitiesListBox->insertItem(act->getDescription(gt.rules));
+		this->notOverlappingActivitiesListWidget->addItem(act->getDescription(gt.rules));
 	}
 	
-	/*
-	for(int i=0; i<ctr->n_activities; i++){
-		int actId=ctr->activitiesId[i];
-		this->notOverlappingActivitiesList << actId ; //append
-		Activity* act=NULL;
-		for(int k=0; k<gt.rules.activitiesList.size(); k++){
-			act=gt.rules.activitiesList[k];
-			if(act->id==actId)
-				break;
-		}
-		assert(act);
-		this->notOverlappingActivitiesListBox->insertItem(act->getDescription(gt.rules));
-	}*/
-	
-	//compulsoryCheckBox->setChecked(ctr->compulsory);
-	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 	
 	////////////////
-	teachersComboBox->insertItem("");
+	teachersComboBox->addItem("");
 	for(int i=0; i<gt.rules.teachersList.size(); i++){
 		Teacher* tch=gt.rules.teachersList[i];
-		teachersComboBox->insertItem(tch->name);
+		teachersComboBox->addItem(tch->name);
 	}
-	teachersComboBox->setCurrentItem(0);
+	teachersComboBox->setCurrentIndex(0);
 
-	subjectsComboBox->insertItem("");
+	subjectsComboBox->addItem("");
 	for(int i=0; i<gt.rules.subjectsList.size(); i++){
 		Subject* sb=gt.rules.subjectsList[i];
-		subjectsComboBox->insertItem(sb->name);
+		subjectsComboBox->addItem(sb->name);
 	}
-	subjectsComboBox->setCurrentItem(0);
+	subjectsComboBox->setCurrentIndex(0);
 
-	activityTagsComboBox->insertItem("");
+	activityTagsComboBox->addItem("");
 	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
 		ActivityTag* st=gt.rules.activityTagsList[i];
-		activityTagsComboBox->insertItem(st->name);
+		activityTagsComboBox->addItem(st->name);
 	}
-	activityTagsComboBox->setCurrentItem(0);
+	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->insertItem("");
+	studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->insertItem(sty->name);
+		studentsComboBox->addItem(sty->name);
 		for(int j=0; j<sty->groupsList.size(); j++){
 			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->insertItem(stg->name);
+			studentsComboBox->addItem(stg->name);
 			for(int k=0; k<stg->subgroupsList.size(); k++){
 				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->insertItem(sts->name);
+				studentsComboBox->addItem(sts->name);
 			}
 		}
 	}
-	studentsComboBox->setCurrentItem(0);
+	studentsComboBox->setCurrentIndex(0);
 
 	filterChanged();
 }
 
 ModifyConstraintActivitiesNotOverlappingForm::~ModifyConstraintActivitiesNotOverlappingForm()
 {
+	saveFETDialogGeometry(this);
 }
 
-/*
-void ModifyConstraintActivitiesNotOverlappingForm::updateActivitiesListBox()
-{
-	activitiesListBox->clear();
-	notOverlappingActivitiesListBox->clear();
-
-	this->activitiesList.clear();
-	this->notOverlappingActivitiesList.clear();
-
-	for(int i=0; i<gt.rules.activitiesList.size(); i++){
-		Activity* ac=gt.rules.activitiesList[i];
-		activitiesListBox->insertItem(ac->getDescription(gt.rules));
-		this->activitiesList.append(ac->id);
-	}
-}*/
-
 void ModifyConstraintActivitiesNotOverlappingForm::filterChanged()
 {
-	activitiesListBox->clear();
-//	selectedActivitiesListBox->clear();
-
+	activitiesListWidget->clear();
 	this->activitiesList.clear();
-//	this->selectedActivitiesList.clear();
 
 	for(int i=0; i<gt.rules.activitiesList.size(); i++){
 		Activity* ac=gt.rules.activitiesList[i];
 		if(filterOk(ac)){
-			activitiesListBox->insertItem(ac->getDescription(gt.rules));
+			activitiesListWidget->addItem(ac->getDescription(gt.rules));
 			this->activitiesList.append(ac->id);
 		}
 	}
+	
+	int q=activitiesListWidget->verticalScrollBar()->minimum();
+	activitiesListWidget->verticalScrollBar()->setValue(q);
 }
 
 bool ModifyConstraintActivitiesNotOverlappingForm::filterOk(Activity* act)
@@ -192,7 +162,6 @@ bool ModifyConstraintActivitiesNotOverlappingForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-//	if(sbtn!="" && sbtn!=act->activityTagName)
 	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
 		ok=false;
 		
@@ -215,17 +184,13 @@ void ModifyConstraintActivitiesNotOverlappingForm::ok()
 {
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid weight (percentage)"));
 		return;
 	}
 
-	/*bool compulsory=false;
-	if(compulsoryCheckBox->isChecked())
-		compulsory=true;*/
-
 	if(this->notOverlappingActivitiesList.count()==0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Empty list of not overlapping activities"));
@@ -236,25 +201,19 @@ void ModifyConstraintActivitiesNotOverlappingForm::ok()
 			tr("Only one selected activity"));
 		return;
 	}
-	/*if(this->notOverlappingActivitiesList.size()>MAX_CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING){
-		QMessageBox::warning(this, tr("FET information"),
-			tr("Please report error to the author\nMAX_CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING must be increased (you have too many activities)"));
-		return;
-	}*/
 	
 	int i;
 	QList<int>::iterator it;
 	this->_ctr->activitiesId.clear();
 	for(i=0, it=this->notOverlappingActivitiesList.begin(); it!=this->notOverlappingActivitiesList.end(); it++, i++){
-		//this->_ctr->activitiesId[i]=*it;
 		this->_ctr->activitiesId.append(*it);
 	}
 	this->_ctr->n_activities=i;
 		
 	this->_ctr->weightPercentage=weight;
-	//this->_ctr->compulsory=compulsory;
 	
 	gt.rules.internalStructureComputed=false;
+	setRulesModifiedAndOtherThings(&gt.rules);
 	
 	this->close();
 }
@@ -266,38 +225,68 @@ void ModifyConstraintActivitiesNotOverlappingForm::cancel()
 
 void ModifyConstraintActivitiesNotOverlappingForm::addActivity()
 {
-	if(activitiesListBox->currentItem()<0)
+	if(activitiesListWidget->currentRow()<0)
 		return;
-	int tmp=activitiesListBox->currentItem();
+	int tmp=activitiesListWidget->currentRow();
 	int _id=this->activitiesList.at(tmp);
 	
-	QString actName=activitiesListBox->currentText();
+	QString actName=activitiesListWidget->currentItem()->text();
 	assert(actName!="");
-	uint i;
+	int i;
 	//duplicate?
-	for(i=0; i<notOverlappingActivitiesListBox->count(); i++)
-		if(actName==notOverlappingActivitiesListBox->text(i))
+	for(i=0; i<notOverlappingActivitiesListWidget->count(); i++)
+		if(actName==notOverlappingActivitiesListWidget->item(i)->text())
 			break;
-	if(i<notOverlappingActivitiesListBox->count())
+	if(i<notOverlappingActivitiesListWidget->count())
 		return;
-	notOverlappingActivitiesListBox->insertItem(actName);
+	notOverlappingActivitiesListWidget->addItem(actName);
+	notOverlappingActivitiesListWidget->setCurrentRow(notOverlappingActivitiesListWidget->count()-1);
 	
 	this->notOverlappingActivitiesList.append(_id);
 }
 
+void ModifyConstraintActivitiesNotOverlappingForm::addAllActivities()
+{
+	for(int tmp=0; tmp<activitiesListWidget->count(); tmp++){
+		int _id=this->activitiesList.at(tmp);
+	
+		QString actName=activitiesListWidget->item(tmp)->text();
+		assert(actName!="");
+		int i;
+		//duplicate?
+		for(i=0; i<notOverlappingActivitiesList.count(); i++)
+			if(notOverlappingActivitiesList.at(i)==_id)
+				break;
+		if(i<notOverlappingActivitiesList.count())
+			continue;
+		
+		notOverlappingActivitiesListWidget->addItem(actName);
+		this->notOverlappingActivitiesList.append(_id);
+	}
+	
+	notOverlappingActivitiesListWidget->setCurrentRow(notOverlappingActivitiesListWidget->count()-1);
+}
+
 void ModifyConstraintActivitiesNotOverlappingForm::removeActivity()
 {
-	if(notOverlappingActivitiesListBox->currentItem()<0 || notOverlappingActivitiesListBox->count()<=0)
-		return;		
-	int tmp=notOverlappingActivitiesListBox->currentItem();
+	if(notOverlappingActivitiesListWidget->currentRow()<0 || notOverlappingActivitiesListWidget->count()<=0)
+		return;
+	int tmp=notOverlappingActivitiesListWidget->currentRow();
 	
-	notOverlappingActivitiesListBox->removeItem(notOverlappingActivitiesListBox->currentItem());
-	this->notOverlappingActivitiesList.removeAt(tmp);
+	notOverlappingActivitiesList.removeAt(tmp);
+
+	notOverlappingActivitiesListWidget->setCurrentRow(-1);
+	QListWidgetItem* item=notOverlappingActivitiesListWidget->takeItem(tmp);
+	delete item;
+	if(tmp<notOverlappingActivitiesListWidget->count())
+		notOverlappingActivitiesListWidget->setCurrentRow(tmp);
+	else
+		notOverlappingActivitiesListWidget->setCurrentRow(notOverlappingActivitiesListWidget->count()-1);
 }
 
 void ModifyConstraintActivitiesNotOverlappingForm::clear()
 {
-	notOverlappingActivitiesListBox->clear();
+	notOverlappingActivitiesListWidget->clear();
 	notOverlappingActivitiesList.clear();
 }
 
