@@ -17,42 +17,32 @@
 
 #include <QMessageBox>
 
-#include <cstdio>
-
 #include "modifyconstraintstudentsactivitytagmaxhoursdailyform.h"
 #include "timeconstraint.h"
 
-ModifyConstraintStudentsActivityTagMaxHoursDailyForm::ModifyConstraintStudentsActivityTagMaxHoursDailyForm(ConstraintStudentsActivityTagMaxHoursDaily* ctr)
+ModifyConstraintStudentsActivityTagMaxHoursDailyForm::ModifyConstraintStudentsActivityTagMaxHoursDailyForm(QWidget* parent, ConstraintStudentsActivityTagMaxHoursDaily* ctr): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-//    connect(weightLineEdit, SIGNAL(textChanged(QString)), this /*ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm_template*/, SLOT(constraintChanged()));
-    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm_template*/, SLOT(ok()));
-    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm_template*/, SLOT(cancel()));
-//    connect(maxHoursSpinBox, SIGNAL(valueChanged(int)), this /*ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm_template*/, SLOT(constraintChanged()));
-//    connect(activityTagsComboBox, SIGNAL(activated(QString)), this /*ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm_template*/, SLOT(constraintChanged()));
+	okPushButton->setDefault(true);
 
+	connect(okPushButton, SIGNAL(clicked()), this, SLOT(ok()));
+	connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(cancel()));
 
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 
 	QSize tmp4=activityTagsComboBox->minimumSizeHint();
 	Q_UNUSED(tmp4);
 	
 	this->_ctr=ctr;
 	
-	//compulsoryCheckBox->setChecked(ctr->compulsory);
-	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 	
 	updateActivityTagsComboBox();
 
-	maxHoursSpinBox->setMinValue(1);
-	maxHoursSpinBox->setMaxValue(gt.rules.nHoursPerDay);
+	maxHoursSpinBox->setMinimum(1);
+	maxHoursSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxHoursSpinBox->setValue(ctr->maxHoursDaily);
 
 	constraintChanged();
@@ -60,6 +50,7 @@ ModifyConstraintStudentsActivityTagMaxHoursDailyForm::ModifyConstraintStudentsAc
 
 ModifyConstraintStudentsActivityTagMaxHoursDailyForm::~ModifyConstraintStudentsActivityTagMaxHoursDailyForm()
 {
+	saveFETDialogGeometry(this);
 }
 
 void ModifyConstraintStudentsActivityTagMaxHoursDailyForm::updateActivityTagsComboBox()
@@ -68,12 +59,12 @@ void ModifyConstraintStudentsActivityTagMaxHoursDailyForm::updateActivityTagsCom
 	int j=-1;
 	for(int i=0; i<gt.rules.activityTagsList.count(); i++){
 		ActivityTag* at=gt.rules.activityTagsList.at(i);
-		activityTagsComboBox->insertItem(at->name);
+		activityTagsComboBox->addItem(at->name);
 		if(at->name==this->_ctr->activityTagName)
 			j=i;
 	}
 	assert(j>=0);
-	activityTagsComboBox->setCurrentItem(j);
+	activityTagsComboBox->setCurrentIndex(j);
 	
 	constraintChanged();
 }
@@ -87,7 +78,7 @@ void ModifyConstraintStudentsActivityTagMaxHoursDailyForm::ok()
 {
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, tr("FET warning"),
 			tr("Invalid weight (percentage)"));
@@ -106,6 +97,7 @@ void ModifyConstraintStudentsActivityTagMaxHoursDailyForm::ok()
 	this->_ctr->maxHoursDaily=maxHoursSpinBox->value();
 
 	gt.rules.internalStructureComputed=false;
+	setRulesModifiedAndOtherThings(&gt.rules);
 	
 	this->close();
 }
