@@ -17,35 +17,27 @@
 
 #include <QMessageBox>
 
-#include <cstdio>
-
 #include "modifyconstraintstudentsmaxbuildingchangesperdayform.h"
 #include "spaceconstraint.h"
 
-ModifyConstraintStudentsMaxBuildingChangesPerDayForm::ModifyConstraintStudentsMaxBuildingChangesPerDayForm(ConstraintStudentsMaxBuildingChangesPerDay* ctr)
+ModifyConstraintStudentsMaxBuildingChangesPerDayForm::ModifyConstraintStudentsMaxBuildingChangesPerDayForm(QWidget* parent, ConstraintStudentsMaxBuildingChangesPerDay* ctr): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-//    connect(weightLineEdit, SIGNAL(textChanged(QString)), this /*ModifyConstraintStudentsMaxBuildingChangesPerDayForm_template*/, SLOT(constraintChanged()));
-    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintStudentsMaxBuildingChangesPerDayForm_template*/, SLOT(ok()));
-    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintStudentsMaxBuildingChangesPerDayForm_template*/, SLOT(cancel()));
-//    connect(maxChangesSpinBox, SIGNAL(valueChanged(int)), this /*ModifyConstraintStudentsMaxBuildingChangesPerDayForm_template*/, SLOT(constraintChanged()));
+	okPushButton->setDefault(true);
 
+	connect(okPushButton, SIGNAL(clicked()), this, SLOT(ok()));
+	connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(cancel()));
 
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 		
 	this->_ctr=ctr;
 	
-	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 	
-	maxChangesSpinBox->setMinValue(0);
-	maxChangesSpinBox->setMaxValue(gt.rules.nHoursPerDay);
+	maxChangesSpinBox->setMinimum(0);
+	maxChangesSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxChangesSpinBox->setValue(ctr->maxBuildingChangesPerDay);
 		
 	constraintChanged();
@@ -53,34 +45,18 @@ ModifyConstraintStudentsMaxBuildingChangesPerDayForm::ModifyConstraintStudentsMa
 
 ModifyConstraintStudentsMaxBuildingChangesPerDayForm::~ModifyConstraintStudentsMaxBuildingChangesPerDayForm()
 {
+	saveFETDialogGeometry(this);
 }
 
 void ModifyConstraintStudentsMaxBuildingChangesPerDayForm::constraintChanged()
-{/*
-	QString s;
-	s+=tr("Current constraint:");
-	s+="\n";
-
-	double weight;
-	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
-	s+=tr(QString("Weight (percentage)=%1\%").arg(weight));
-	s+="\n";
-
-	s+=tr("Students max building changes per day");
-	s+="\n";
-	
-	s+=tr("Max building changes per day=%1").arg(maxChangesSpinBox->value());
-	s+="\n";
-
-	currentConstraintTextEdit->setText(s);*/
+{
 }
 
 void ModifyConstraintStudentsMaxBuildingChangesPerDayForm::ok()
 {
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<100.0 || weight>100.0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid weight (percentage). It has to be 100"));
@@ -91,6 +67,7 @@ void ModifyConstraintStudentsMaxBuildingChangesPerDayForm::ok()
 	this->_ctr->maxBuildingChangesPerDay=maxChangesSpinBox->value();
 
 	gt.rules.internalStructureComputed=false;
+	setRulesModifiedAndOtherThings(&gt.rules);
 	
 	this->close();
 }
