@@ -15,74 +15,49 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <cstdio>
+
 
 #include "modifyconstraintteachersmindaysperweekform.h"
 #include "timeconstraint.h"
 
 #include <QMessageBox>
 
-ModifyConstraintTeachersMinDaysPerWeekForm::ModifyConstraintTeachersMinDaysPerWeekForm(ConstraintTeachersMinDaysPerWeek* ctr)
+ModifyConstraintTeachersMinDaysPerWeekForm::ModifyConstraintTeachersMinDaysPerWeekForm(QWidget* parent, ConstraintTeachersMinDaysPerWeek* ctr): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-//    connect(weightLineEdit, SIGNAL(textChanged(QString)), this /*ModifyConstraintTeachersMaxDaysPerWeekForm_template*/, SLOT(constraintChanged()));
-    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintTeachersMaxDaysPerWeekForm_template*/, SLOT(ok()));
-    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintTeachersMaxDaysPerWeekForm_template*/, SLOT(cancel()));
-//    connect(maxDaysSpinBox, SIGNAL(valueChanged(int)), this /*ModifyConstraintTeachersMaxDaysPerWeekForm_template*/, SLOT(constraintChanged()));
+	okPushButton->setDefault(true);
 
+	connect(okPushButton, SIGNAL(clicked()), this, SLOT(ok()));
+	connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(cancel()));
 
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 	
 	this->_ctr=ctr;
 	
-	//compulsoryCheckBox->setChecked(ctr->compulsory);
-	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 	
 	updateMinDaysSpinBox();
-	//updateTeachersComboBox();
 	
 	minDaysSpinBox->setValue(ctr->minDaysPerWeek);
-
-	//constraintChanged();
 }
 
 ModifyConstraintTeachersMinDaysPerWeekForm::~ModifyConstraintTeachersMinDaysPerWeekForm()
 {
+	saveFETDialogGeometry(this);
 }
 
-/*
-void ModifyConstraintTeachersMaxDaysPerWeekForm::updateTeachersComboBox(){
-	teachersComboBox->clear();
-	int i=0, j=-1;
-	for(int k=0; k<gt.rules.teachersList.size(); k++, i++){
-		Teacher* tch=gt.rules.teachersList[k];
-		teachersComboBox->insertItem(tch->name);
-		if(tch->name==this->_ctr->teacherName)
-			j=i;
-	}
-	assert(j>=0);
-	teachersComboBox->setCurrentItem(j);
-
-	constraintChanged();
-}*/
-
 void ModifyConstraintTeachersMinDaysPerWeekForm::updateMinDaysSpinBox(){
-	minDaysSpinBox->setMinValue(1);
-	minDaysSpinBox->setMaxValue(gt.rules.nDaysPerWeek);	
+	minDaysSpinBox->setMinimum(1);
+	minDaysSpinBox->setMaximum(gt.rules.nDaysPerWeek);	
 }
 
 void ModifyConstraintTeachersMinDaysPerWeekForm::ok()
 {
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid weight (percentage)"));
@@ -94,26 +69,13 @@ void ModifyConstraintTeachersMinDaysPerWeekForm::ok()
 		return;
 	}
 
-	/*bool compulsory=false;
-	if(compulsoryCheckBox->isChecked())
-		compulsory=true;*/
-
 	int min_days=minDaysSpinBox->value();
 
-	/*QString teacher_name=teachersComboBox->currentText();
-	int teacher_ID=gt.rules.searchTeacher(teacher_name);
-	if(teacher_ID<0){
-		QMessageBox::warning(this, tr("FET information"),
-			tr("Invalid teacher"));
-		return;
-	}*/
-
 	this->_ctr->weightPercentage=weight;
-	//this->_ctr->compulsory=compulsory;
 	this->_ctr->minDaysPerWeek=min_days;
-	//this->_ctr->teacherName=teacher_name;
 
 	gt.rules.internalStructureComputed=false;
+	setRulesModifiedAndOtherThings(&gt.rules);
 	
 	this->close();
 }
