@@ -17,26 +17,20 @@
 
 #include <QMessageBox>
 
-#include <cstdio>
-
 #include "modifyconstraintthreeactivitiesgroupedform.h"
 #include "timeconstraint.h"
 
-ModifyConstraintThreeActivitiesGroupedForm::ModifyConstraintThreeActivitiesGroupedForm(ConstraintThreeActivitiesGrouped* ctr)
+ModifyConstraintThreeActivitiesGroupedForm::ModifyConstraintThreeActivitiesGroupedForm(QWidget* parent, ConstraintThreeActivitiesGrouped* ctr): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintThreeActivitiesGroupedForm_template*/, SLOT(ok()));
-    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintThreeActivitiesGroupedForm_template*/, SLOT(cancel()));
+	okPushButton->setDefault(true);
 
+	connect(okPushButton, SIGNAL(clicked()), this, SLOT(ok()));
+	connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(cancel()));
 
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 
 	QSize tmp5=firstActivitiesComboBox->minimumSizeHint();
 	Q_UNUSED(tmp5);
@@ -51,15 +45,14 @@ ModifyConstraintThreeActivitiesGroupedForm::ModifyConstraintThreeActivitiesGroup
 	
 	this->_ctr=ctr;
 	
-	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 
 	updateActivitiesComboBox();
-
-	//constraintChanged();
 }
 
 ModifyConstraintThreeActivitiesGroupedForm::~ModifyConstraintThreeActivitiesGroupedForm()
 {
+	saveFETDialogGeometry(this);
 }
 
 bool ModifyConstraintThreeActivitiesGroupedForm::filterOk(Activity* act)
@@ -90,7 +83,7 @@ void ModifyConstraintThreeActivitiesGroupedForm::updateActivitiesComboBox(){
 	for(int k=0; k<gt.rules.activitiesList.size(); k++){
 		Activity* act=gt.rules.activitiesList[k];
 		if(filterOk(act)){
-			firstActivitiesComboBox->insertItem(act->getDescription(gt.rules));
+			firstActivitiesComboBox->addItem(act->getDescription(gt.rules));
 			this->firstActivitiesList.append(act->id);
 
 			if(act->id==this->_ctr->firstActivityId)
@@ -100,13 +93,13 @@ void ModifyConstraintThreeActivitiesGroupedForm::updateActivitiesComboBox(){
 		}
 	}
 	//assert(j>=0); only first time
-	firstActivitiesComboBox->setCurrentItem(j);
+	firstActivitiesComboBox->setCurrentIndex(j);
 
 	i=0, j=-1;
 	for(int k=0; k<gt.rules.activitiesList.size(); k++){
 		Activity* act=gt.rules.activitiesList[k];
 		if(filterOk(act)){
-			secondActivitiesComboBox->insertItem(act->getDescription(gt.rules));
+			secondActivitiesComboBox->addItem(act->getDescription(gt.rules));
 			this->secondActivitiesList.append(act->id);
 
 			if(act->id==this->_ctr->secondActivityId)
@@ -116,13 +109,13 @@ void ModifyConstraintThreeActivitiesGroupedForm::updateActivitiesComboBox(){
 		}
 	}
 	//assert(j>=0); only first time
-	secondActivitiesComboBox->setCurrentItem(j);
+	secondActivitiesComboBox->setCurrentIndex(j);
 
 	i=0, j=-1;
 	for(int k=0; k<gt.rules.activitiesList.size(); k++){
 		Activity* act=gt.rules.activitiesList[k];
 		if(filterOk(act)){
-			thirdActivitiesComboBox->insertItem(act->getDescription(gt.rules));
+			thirdActivitiesComboBox->addItem(act->getDescription(gt.rules));
 			this->thirdActivitiesList.append(act->id);
 
 			if(act->id==this->_ctr->thirdActivityId)
@@ -132,85 +125,21 @@ void ModifyConstraintThreeActivitiesGroupedForm::updateActivitiesComboBox(){
 		}
 	}
 	//assert(j>=0); only first time
-	thirdActivitiesComboBox->setCurrentItem(j);
-
-	//constraintChanged();
+	thirdActivitiesComboBox->setCurrentIndex(j);
 }
 
-/*void ModifyConstraintThreeActivitiesGroupedForm::constraintChanged()
-{
-	QString s;
-	s+=tr("Current constraint:");
-	s+="\n";
-
-	double weight;
-	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
-	s+=tr("Weight (percentage)=%1\%").arg(weight);
-	s+="\n";
-
-	s+=tr("3 activities grouped");
-	s+=" ";
-	s+=tr("(activities must be in the same day, one following the other, in any order, possibly separated by breaks)");
-	s+="\n";
-	
-	int fid;
-	int tmp2=firstActivitiesComboBox->currentItem();
-	assert(tmp2<gt.rules.activitiesList.size());
-	assert(tmp2<firstActivitiesList.size());
-	if(tmp2<0){
-		s+=tr("Invalid activity");
-		s+="\n";
-	}
-	else{
-		fid=firstActivitiesList.at(tmp2);
-		s+=tr("First activity id=%1").arg(fid);
-		s+="\n";
-	}
-
-	int sid;
-	int tmp3=secondActivitiesComboBox->currentItem();
-	assert(tmp3<gt.rules.activitiesList.size());
-	assert(tmp3<secondActivitiesList.size());
-	if(tmp3<0){
-		s+=tr("Invalid second activity");
-		s+="\n";
-	}
-	else{
-		sid=secondActivitiesList.at(tmp3);
-		s+=tr("Second activity id=%1").arg(sid);
-		s+="\n";
-	}
-
-	int tid;
-	int tmp4=thirdActivitiesComboBox->currentItem();
-	assert(tmp4<gt.rules.activitiesList.size());
-	assert(tmp4<thirdActivitiesList.size());
-	if(tmp4<0){
-		s+=tr("Invalid third activity");
-		s+="\n";
-	}
-	else{
-		tid=thirdActivitiesList.at(tmp4);
-		s+=tr("Third activity id=%1").arg(tid);
-		s+="\n";
-	}
-
-	currentConstraintTextEdit->setText(s);
-}*/
-
 void ModifyConstraintThreeActivitiesGroupedForm::ok()
 {
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid weight (percentage)"));
 		return;
 	}
 
-	int tmp2=firstActivitiesComboBox->currentItem();
+	int tmp2=firstActivitiesComboBox->currentIndex();
 	assert(tmp2<gt.rules.activitiesList.size());
 	assert(tmp2<firstActivitiesList.size());
 	if(tmp2<0){
@@ -220,7 +149,7 @@ void ModifyConstraintThreeActivitiesGroupedForm::ok()
 	}
 	int fid=firstActivitiesList.at(tmp2);
 	
-	int tmp3=secondActivitiesComboBox->currentItem();
+	int tmp3=secondActivitiesComboBox->currentIndex();
 	assert(tmp3<gt.rules.activitiesList.size());
 	assert(tmp3<secondActivitiesList.size());
 	if(tmp3<0){
@@ -230,7 +159,7 @@ void ModifyConstraintThreeActivitiesGroupedForm::ok()
 	}
 	int sid=secondActivitiesList.at(tmp3);
 
-	int tmp4=thirdActivitiesComboBox->currentItem();
+	int tmp4=thirdActivitiesComboBox->currentIndex();
 	assert(tmp4<gt.rules.activitiesList.size());
 	assert(tmp4<thirdActivitiesList.size());
 	if(tmp4<0){
@@ -252,6 +181,7 @@ void ModifyConstraintThreeActivitiesGroupedForm::ok()
 	this->_ctr->thirdActivityId=tid;
 	
 	gt.rules.internalStructureComputed=false;
+	setRulesModifiedAndOtherThings(&gt.rules);
 
 	this->close();
 }
