@@ -32,7 +32,7 @@ class ModifyRoomForm : public QDialog, Ui::ModifyRoomForm_template {
 	QString _initialRoomBuilding;
 	int _initialRoomCapacity;
 public: 
-	ModifyRoomForm(const QString& initialRoomName/*, const QString& initialRoomType*/, const QString& initialRoomBuilding, int initialRoomCapacity);
+	ModifyRoomForm(QWidget* parent, const QString& initialRoomName, const QString& initialRoomBuilding, int initialRoomCapacity);
 	~ModifyRoomForm();
 
 public slots:
