@@ -19,24 +19,20 @@
 
 #include <QMessageBox>
 
-ModifyStudentsYearForm::ModifyStudentsYearForm(const QString& initialYearName, int initialNumberOfStudents)
+ModifyStudentsYearForm::ModifyStudentsYearForm(QWidget* parent, const QString& initialYearName, int initialNumberOfStudents): QDialog(parent)
 {
-    setupUi(this);
-
-    connect(okPushButton, SIGNAL(clicked()), this /*ModifyStudentsYearForm_template*/, SLOT(ok()));
-    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyStudentsYearForm_template*/, SLOT(cancel()));
-
-
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
-	centerWidgetOnScreen(this);
+	setupUi(this);
 	
-	numberSpinBox->setMaxValue(MAX_ROOM_CAPACITY);
-	numberSpinBox->setMinValue(0);
+	okPushButton->setDefault(true);
+
+	connect(okPushButton, SIGNAL(clicked()), this, SLOT(ok()));
+	connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(cancel()));
+
+	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
+	
+	numberSpinBox->setMaximum(MAX_ROOM_CAPACITY);
+	numberSpinBox->setMinimum(0);
 	numberSpinBox->setValue(0);
 
 	this->_initialYearName=initialYearName;
@@ -49,6 +45,7 @@ ModifyStudentsYearForm::ModifyStudentsYearForm(const QString& initialYearName, i
 
 ModifyStudentsYearForm::~ModifyStudentsYearForm()
 {
+	saveFETDialogGeometry(this);
 }
 
 void ModifyStudentsYearForm::cancel()
