@@ -14,8 +14,6 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-//
-//
 
 #include "timetable_defs.h"
 #include "timetable.h"
@@ -27,53 +25,69 @@
 
 #include <QMessageBox>
 
-TeachersForm::TeachersForm()
- : TeachersForm_template()
+#include <QListWidget>
+#include <QAbstractItemView>
+
+#include <QSplitter>
+#include <QSettings>
+#include <QObject>
+#include <QMetaObject>
+
+extern const QString COMPANY;
+extern const QString PROGRAM;
+
+TeachersForm::TeachersForm(QWidget* parent): QDialog(parent)
 {
-    setupUi(this);
-
-    connect(renameTeacherPushButton, SIGNAL(clicked()), this /*TeachersForm_template*/, SLOT(renameTeacher()));
-    connect(closePushButton, SIGNAL(clicked()), this /*TeachersForm_template*/, SLOT(close()));
-    connect(addTeacherPushButton, SIGNAL(clicked()), this /*TeachersForm_template*/, SLOT(addTeacher()));
-    connect(sortTeachersPushButton, SIGNAL(clicked()), this /*TeachersForm_template*/, SLOT(sortTeachers()));
-    connect(removeTeacherPushButton, SIGNAL(clicked()), this /*TeachersForm_template*/, SLOT(removeTeacher()));
-    connect(teachersListBox, SIGNAL(highlighted(int)), this /*TeachersForm_template*/, SLOT(teacherChanged(int)));
-    connect(activateTeacherPushButton, SIGNAL(clicked()), this /*TeachersForm_template*/, SLOT(activateTeacher()));
-    connect(deactivateTeacherPushButton, SIGNAL(clicked()), this /*TeachersForm_template*/, SLOT(deactivateTeacher()));
-    connect(teachersListBox, SIGNAL(selected(QString)), this /*TeachersForm_template*/, SLOT(renameTeacher()));
-
-
-	//setWindowFlags(Qt::Window);
-	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
-	centerWidgetOnScreen(this);
+	setupUi(this);
 	
-	teachersListBox->clear();
+	currentTeacherTextEdit->setReadOnly(true);
+
+	renameTeacherPushButton->setDefault(true);
+
+	teachersListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+
+	connect(renameTeacherPushButton, SIGNAL(clicked()), this, SLOT(renameTeacher()));
+	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
+	connect(addTeacherPushButton, SIGNAL(clicked()), this, SLOT(addTeacher()));
+	connect(sortTeachersPushButton, SIGNAL(clicked()), this, SLOT(sortTeachers()));
+	connect(removeTeacherPushButton, SIGNAL(clicked()), this, SLOT(removeTeacher()));
+	connect(teachersListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(teacherChanged(int)));
+	connect(activateTeacherPushButton, SIGNAL(clicked()), this, SLOT(activateTeacher()));
+	connect(deactivateTeacherPushButton, SIGNAL(clicked()), this, SLOT(deactivateTeacher()));
+	connect(teachersListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(renameTeacher()));
+
+	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
+	//restore splitter state
+	QSettings settings(COMPANY, PROGRAM);
+	if(settings.contains(this->metaObject()->className()+QString("/splitter-state")))
+		splitter->restoreState(settings.value(this->metaObject()->className()+QString("/splitter-state")).toByteArray());
+	
+	teachersListWidget->clear();
 	for(int i=0; i<gt.rules.teachersList.size(); i++){
 		Teacher* tch=gt.rules.teachersList[i];
-		teachersListBox->insertItem(tch->name);
-	}
-		
-	if(teachersListBox->count()>0){
-		teachersListBox->setCurrentItem(0);
-		this->teacherChanged(0);
+		teachersListWidget->addItem(tch->name);
 	}
+	
+	if(teachersListWidget->count()>0)
+		teachersListWidget->setCurrentRow(0);
 }
 
 
 TeachersForm::~TeachersForm()
 {
+	saveFETDialogGeometry(this);
+	//save splitter state
+	QSettings settings(COMPANY, PROGRAM);
+	settings.setValue(this->metaObject()->className()+QString("/splitter-state"), splitter->saveState());
 }
 
 void TeachersForm::addTeacher()
 {
 	bool ok = FALSE;
 	Teacher* tch=new Teacher();
-	tch->name = QInputDialog::getText( tr("User input"), tr("Please enter teacher's name") ,
-                    QLineEdit::Normal, QString::null, &ok, this );
+	tch->name = QInputDialog::getText( this, tr("Add teacher"), tr("Please enter teacher's name") ,
+	 QLineEdit::Normal, QString(), &ok );
 
 	if ( ok && !((tch->name).isEmpty()) ){
 		// user entered something and pressed OK
@@ -83,24 +97,27 @@ void TeachersForm::addTeacher()
 			delete tch;
 		}
 		else{
-			teachersListBox->insertItem(tch->name);
-			teachersListBox->setCurrentItem(teachersListBox->count()-1);
-			this->teacherChanged(teachersListBox->count()-1);
+			teachersListWidget->addItem(tch->name);
+			teachersListWidget->setCurrentRow(teachersListWidget->count()-1);
 		}
 	}
-	else
+	else{
+		if(ok){ //the user entered nothing
+			QMessageBox::information(this, tr("FET information"), tr("Incorrect name"));
+		}
 		delete tch;// user entered nothing or pressed Cancel
+	}
 }
 
 void TeachersForm::removeTeacher()
 {
-	int i=teachersListBox->currentItem();
-	if(teachersListBox->currentItem()<0){
+	int i=teachersListWidget->currentRow();
+	if(teachersListWidget->currentRow()<0){
 		QMessageBox::information(this, tr("FET information"), tr("Invalid selected teacher"));
 		return;
 	}
 
-	QString text=teachersListBox->currentText();
+	QString text=teachersListWidget->currentItem()->text();
 	int teacher_ID=gt.rules.searchTeacher(text);
 	if(teacher_ID<0){
 		QMessageBox::information(this, tr("FET information"), tr("Invalid selected teacher"));
@@ -114,23 +131,29 @@ void TeachersForm::removeTeacher()
 
 	int tmp=gt.rules.removeTeacher(text);
 	if(tmp){
-		teachersListBox->removeItem(teachersListBox->currentItem());
-		if((uint)(i)>=teachersListBox->count())
-			i=teachersListBox->count()-1;
-		teachersListBox->setCurrentItem(i);
-		this->teacherChanged(i);		
+		teachersListWidget->setCurrentRow(-1);
+		QListWidgetItem* item;
+		item=teachersListWidget->takeItem(i);
+		delete item;
+
+		if(i>=teachersListWidget->count())
+			i=teachersListWidget->count()-1;
+		if(i>=0)
+			teachersListWidget->setCurrentRow(i);
+		else
+			currentTeacherTextEdit->setPlainText(QString(""));
 	}
 }
 
 void TeachersForm::renameTeacher()
 {
-	int i=teachersListBox->currentItem();
-	if(teachersListBox->currentItem()<0){
+	int i=teachersListWidget->currentRow();
+	if(teachersListWidget->currentRow()<0){
 		QMessageBox::information(this, tr("FET information"), tr("Invalid selected teacher"));
 		return;
 	}
 
-	QString initialTeacherName=teachersListBox->currentText();
+	QString initialTeacherName=teachersListWidget->currentItem()->text();
 	int teacher_ID=gt.rules.searchTeacher(initialTeacherName);
 	if(teacher_ID<0){
 		QMessageBox::information(this, tr("FET information"), tr("Invalid selected teacher"));
@@ -139,8 +162,8 @@ void TeachersForm::renameTeacher()
 
 	bool ok = FALSE;
 	QString finalTeacherName;
-	finalTeacherName = QInputDialog::getText( tr("User input"), tr("Please enter new teacher's name") ,
-                    QLineEdit::Normal, initialTeacherName, &ok, this );
+	finalTeacherName = QInputDialog::getText( this, tr("Modify teacher"), tr("Please enter new teacher's name") ,
+	 QLineEdit::Normal, initialTeacherName, &ok);
 
 	if ( ok && !(finalTeacherName.isEmpty())){
 		// user entered something and pressed OK
@@ -150,7 +173,8 @@ void TeachersForm::renameTeacher()
 		}
 		else{
 			gt.rules.modifyTeacher(initialTeacherName, finalTeacherName);
-			teachersListBox->changeItem(finalTeacherName, i);
+			teachersListWidget->item(i)->setText(finalTeacherName);
+			teacherChanged(teachersListWidget->currentRow());
 		}
 	}
 }
@@ -159,47 +183,49 @@ void TeachersForm::sortTeachers()
 {
 	gt.rules.sortTeachersAlphabetically();
 
-	teachersListBox->clear();
+	teachersListWidget->clear();
 	for(int i=0; i<gt.rules.teachersList.size(); i++){
 		Teacher* tch=gt.rules.teachersList[i];
-		teachersListBox->insertItem(tch->name);
+		teachersListWidget->addItem(tch->name);
 	}
+	
+	if(teachersListWidget->count()>0)
+		teachersListWidget->setCurrentRow(0);
 }
 
 void TeachersForm::teacherChanged(int index)
 {
 	if(index<0){
-		//currentTeacherTextEdit->setText(tr("Invalid teacher"));
-		currentTeacherTextEdit->setText("");
+		currentTeacherTextEdit->setPlainText("");
 		return;
 	}
 	
 	Teacher* t=gt.rules.teachersList.at(index);
 	assert(t);
 	QString s=t->getDetailedDescriptionWithConstraints(gt.rules);
-	currentTeacherTextEdit->setText(s);
+	currentTeacherTextEdit->setPlainText(s);
 }
 
 void TeachersForm::activateTeacher()
 {
-	if(teachersListBox->currentItem()<0){
+	if(teachersListWidget->currentRow()<0){
 		QMessageBox::information(this, tr("FET information"), tr("Invalid selected teacher"));
 		return;
 	}
 
-	QString teacherName=teachersListBox->currentText();
+	QString teacherName=teachersListWidget->currentItem()->text();
 	int count=gt.rules.activateTeacher(teacherName);
 	QMessageBox::information(this, tr("FET information"), tr("Activated a number of %1 activities").arg(count));
 }
 
 void TeachersForm::deactivateTeacher()
 {
-	if(teachersListBox->currentItem()<0){
+	if(teachersListWidget->currentRow()<0){
 		QMessageBox::information(this, tr("FET information"), tr("Invalid selected teacher"));
 		return;
 	}
 
-	QString teacherName=teachersListBox->currentText();
+	QString teacherName=teachersListWidget->currentItem()->text();
 	int count=gt.rules.deactivateTeacher(teacherName);
 	QMessageBox::information(this, tr("FET information"), tr("De-activated a number of %1 activities").arg(count));
 }
